@@ -4,13 +4,13 @@ from django.shortcuts import redirect
 from django.urls import reverse
 
 
-def admin_required(function):
+def staff_required(function):
     """Decorator for requiring admin permission"""
     def wrap(request, *args, **kwargs):
         """Wrap function of decorator"""
         if not request.user.is_authenticated:
             return redirect(reverse('account_login'))
-        if request.user.is_superuser:
+        if request.user.is_staff:
             return function(request, *args, **kwargs)
         return redirect(reverse('base:home'))
 
