@@ -166,7 +166,10 @@ def sync_demoddata_to_db(frame):
 
     try:
         # need to abstract the timestamp from the filename. hacky..
-        file_datetime = frame.payload_demod.name.split('/')[2].split('_')[2]
+        if frame.payload_demod:
+            file_datetime = frame.payload_demod.name.split('/')[-1].split('_')[2]
+        else:
+            file_datetime = frame.demodulated_data.name.split('/')[-1].split('_')[2]
         frame_datetime = datetime.strptime(file_datetime, '%Y-%m-%dT%H-%M-%S')
         submit_datetime = datetime.strftime(frame_datetime, '%Y-%m-%dT%H:%M:%S.000Z')
     except ValueError:
